# TextFlows Core Module #


A [TextFlows](https://github.com/xflows/textflows/) package, which contains the core classes for representing an annotated document corpus, as well as text mining widgets (UI components) based on [NLTK](http://www.nltk.org/). The package can also be used with [ClowdFlows](https://github.com/xflows/clowdflows/) 2.0.

[![Documentation Status](https://readthedocs.org/projects/rdm/badge/?version=latest)](http://docs.textflows.org/)

Currently, the project contains several components for text preprocessing: tokenization, stop word removal, lemmatization, part-of-speech tagging, etc.


## Installation, documentation ##

Please find installation instructions, examples and API reference on [Read the Docs](http://docs.textflows.org/).

## Note ##

Please note that this is a research project and that drastic changes can be (and are) made pretty regularly. Changes are documented in the [CHANGELOG](CHANGELOG.md).

Pull requests and issues are welcome.

## Contributors to the tf_core package code ##

Matic Perovšek (@mperice), Matej Martinc (@matejMartinc), Roman Orač (@romanorac)

* [Knowldge Technologies Department](http://kt.ijs.si), Jožef Stefan Institute, Ljubljana